#
# spec file for package ogre
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major 13
%define minor 6
%define third 5
%define sover  %{major}.%{minor}
%define soname %{major}_%{minor}
%define plugin_dir %{_libdir}/OGRE%{soname}
# Version from https://github.com/OGRECave/ogre/blob/v%version/Components/Overlay/CMakeLists.txt#L25
%define im_version 1.87
# CG is non free, so not build by default
%bcond_with cg
# OpenEXR v3 is incompatible https://github.com/OGRECave/ogre/issues/2179
%bcond_with openexr
# Optionally build without mono bindings
%bcond_with mono
Name:           ogre
Version:        %{major}.%{minor}.%{third}
Release:        3.5
Summary:        Object-Oriented Graphics Rendering Engine
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://www.ogre3d.org/
Source0:        https://github.com/OGRECave/ogre/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/ocornut/imgui/archive/v%{im_version}.tar.gz#/imgui-%{im_version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE python3-sitelib.patch -- Fix python path detected on build time
Patch0:         python3-sitelib.patch
# PATCH-FEAT-UPSTREAM 0001-Vulkan-Use-find_package-to-support-system-wide-insta.patch
Patch1:         0001-Vulkan-Use-find_package-to-support-system-wide-insta.patch
# PATCH-FIX-UPSTREAM fix-sse-detection.patch -- Fix detection of sse for x86 (vs x64)
Patch2:         fix-sse-detection.patch
Patch3:         swig-3-cpp11.patch
# PATCH-FIX-OPENSUSE fix-gslang-cpp17.patch -- Our GLSlang package requires c++17
Patch4:         fix-gslang-cpp17.patch
Patch5:         fix-glslang-plugin-compilation.patch
BuildRequires:  cmake >= 3.10
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  freeimage-devel
BuildRequires:  gcc-c++
BuildRequires:  glslang-devel
BuildRequires:  glslang-nonstd-devel
BuildRequires:  imgui-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  swig
BuildRequires:  cmake(SPIRV-Tools)
BuildRequires:  cmake(assimp)
%if %{with mono}
BuildRequires:  mono(mcs)
%endif
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(shaderc)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zziplib)
Obsoletes:      libOgreMain <= %{version}
%if %{with cg}
BuildRequires:  cg-devel
%endif
%if %{with openexr}
BuildRequires:  pkgconfig(OpenEXR) < 3.0
%endif

%description
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible
3D engine written in C++ designed to make it easier and more intuitive for
developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

%package media
Summary:        Required media files for OGRE
# There must only one media package installed! As using programs hardcode the path
Conflicts:      %{name}-media < %{version}

%description media
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the required media files for OGRE, optional files are provided
with the %{name}-demos package.

%package mono
Summary:        Mono bindings OGRE
Group:          Development/Libraries/C and C++

%description mono
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

%package python
Summary:        Python bindings for OGRE
Group:          Development/Libraries/C and C++

%description python
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

%package -n libOgreMain%{soname}
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries
Recommends:     %{name}-media >= %{version}
Recommends:     libOgreMain%{soname}-codecs
Recommends:     libOgreMain%{soname}-plugins

%description -n libOgreMain%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible
3D engine written in C++ designed to make it easier and more intuitive for
developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

%package -n libOgreBites%{soname}
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries

%description -n libOgreBites%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.
Reusable utilities for rapid prototyping with Ogre.

%package -n libOgreBitesQt%{soname}
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries

%description -n libOgreBitesQt%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.
Reusable utilities for rapid prototyping with Ogre.

%package -n libOgreMeshLodGenerator%{soname}
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries

%description -n libOgreMeshLodGenerator%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.
Mesh LOD allows to swap the models to Low-poly models in far distance, which makes your game faster.

%package -n libOgreMain%{soname}-codecs
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries
Provides:       libOgreMain-codecs = %{version}

%description -n libOgreMain%{soname}-codecs
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

%package -n libOgreMain%{soname}-plugins
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries
Provides:       libOgreMain-plugins = %{version}
Conflicts:      libOgreMain-plugins <= 1.12.13
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description -n libOgreMain%{soname}-plugins
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

%if %{with cg}
%package -n libOgreMain%{soname}-plugin-Cg
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries
Provides:       libOgreMain-plugin-Cg = %{version}

%description -n libOgreMain%{soname}-plugin-Cg
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the Cg plugin.
%endif

%package -n libOgrePaging%{soname}
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries

%description -n libOgrePaging%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

The Paging Scene Manager allows scenes to be split into a set of pages. Only
those pages that are being used need be loaded at any given time, allowing
arbitrarily large scenes. Each page has its own heightmap, to which several
textures can be applied by height.

%package -n libOgreProperty%{soname}
Summary:        Ogre 3D: an open source graphics engine
Group:          System/Libraries

%description -n libOgreProperty%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

OGRE's property system allows you to associate values of arbitrary type with
names, and have those values exposed via a self-describing interface.

%package -n libOgreOverlay%{soname}
Summary:        Ogre Overlay library
Group:          System/Libraries

%description -n libOgreOverlay%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

An overlay is an additional plane that is layed over the finished render of a
scene. Commonly, scores or interaction menus for the player are positioned
there. In the Ogre demos, overlays are used to display the Ogre logo as well as
current information about the scene, such as polygon count or current frames
per second.

%package -n libOgreVolume%{soname}
Summary:        Ogre Volume component
Group:          System/Libraries

%description -n libOgreVolume%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains a component to render volumes. It can handle any volume
data, but featurewise has a tedency towards terrains. The terrain aspect means
that it is all about huge meshes being displayed with a level of detail
mechanism. Thanks to volume rendering, caves, cliffes, holes and similar
geometry can be displayed.

* Volume Rendering via Dual Marching Cubes.
* LOD mechanism via a chunk tree and marching squares skirts for crack
  patching.
* Data Sources: 3D Textures with density values and the ability to buildup a
  CSG Tree with 3D Textures, Spheres, Cubes, Planes, Intersection, Union,
  Difference and Negation, SimplexNoise addition.
* An own compressible file format for discrete density values.

%package -n libOgreRTShaderSystem%{soname}
Summary:        Ogre Runtime Shader System
Group:          System/Libraries

%description -n libOgreRTShaderSystem%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This component is used to generate shaders on the fly, based on object material
properties, scene setup and other user definitions.

* Runtime shader generation synchronized with scene state. Each time scene
  settings change, a new set of shaders is generated.
* Full FFP (Fixed Function Pipeline) emulation. This feature is most useful
  combined with render system that does not provide any FFP functionality
  (OpenGL ES 2.0, D3D10, D3D11, etc.).
* Shader language independent interface: the logic representation of the shader
  programs is completely independent from the target shader language.
* Pluggable interface allows extending the target shader languages set and
  adding new shader-based effects to the system in a seamless way. Each effect
  code will be automatically combined with the rest of the shader code.
* Automatic vertex shader compacting mechanism: no more compacting variables by
  hand. In case the amount of used vertex shader output registers exceeds the
  maximum allowed (12 to 32, depending on D3DPSHADERCAPS2_0.NumTemps(external
  link)), a compacting algorithm packs the vertex shader outputs and adds
  unpack code in the fragment shader side.
* Material script support, for both export and import.

%package -n libOgreTerrain%{soname}
Summary:        Ogre Terrain System component
Group:          System/Libraries

%description -n libOgreTerrain%{soname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.
The Ogre Terrain System features:

* SceneManager independent, integrates with (optional) Paging component
* Hierarchical geometry batching: batch count reduced at lower LODs as well as
  vertex count. At the lowest level of detail, the entire terrain page is a
  single batch which has obvious advantages for large paging terrains over the
  fixed tiles previously used.
* Skirts are used instead of stitching to avoid cracks in geometry. This means
  fewer indexing arrangements and lower overall index buffer usage.
* Built-in support for splatting layers, configurable sampler inputs and
  pluggable material generators.
* Support for generating global normal maps and light maps in a background
  thread.
* LOD now adapts in real-time to camera settings (viewport sizes & LOD bias) so
  you can use the same terrain with multiple views efficiently.

%package -n libOgreMain-devel
Summary:        Development files for the Ogre Main library
Group:          Development/Libraries/C and C++
Requires:       libOgreMain%{soname} = %{version}
Requires:       libOgreMain%{soname}-codecs = %{version}
Requires:       libOgreMain%{soname}-plugins = %{version}
Requires:       ogre-media
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xaw7)
Requires:       pkgconfig(xrandr)
Requires:       pkgconfig(zziplib)

%description -n libOgreMain-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

%package -n libOgreBites-devel
Summary:        Development headers for rapid prototyping
Group:          Development/Libraries/C and C++
Requires:       libOgreBites%{soname} = %{version}
Requires:       libOgreBitesQt%{soname} = %{version}

%description -n libOgreBites-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

Reusable utilities for rapid prototyping with Ogre.

%package -n libOgreMeshLodGenerator-devel
Summary:        Development headers for Mesh LOD
Group:          Development/Libraries/C and C++
Requires:       libOgreMeshLodGenerator%{soname} = %{version}

%description -n libOgreMeshLodGenerator-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.
Mesh LOD allows to swap the models to Low-poly models in far distance, which makes your game faster.

%package -n libOgrePaging-devel
Summary:        Development headers for the Ogre Paging Scene Manager component
Group:          Development/Libraries/C and C++
Requires:       libOgrePaging%{soname} = %{version}

%description -n libOgrePaging-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

The Paging Scene Manager allows scenes to be split into a set of pages. Only
those pages that are being used need be loaded at any given time, allowing
arbitrarily large scenes. Each page has its own heightmap, to which several
textures can be applied by height.

This package contains the development headers for the Paging Scene Manager
component.

%package -n libOgreProperty-devel
Summary:        Development files for the Ogre Property component
Group:          Development/Libraries/C and C++
Requires:       libOgreProperty%{soname} = %{version}

%description -n libOgreProperty-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the development headers for the property component.

%package -n libOgreOverlay-devel
Summary:        Development files for the Ogre Overlay component
Group:          Development/Libraries/C and C++
Requires:       libOgreOverlay%{soname} = %{version}

%description -n libOgreOverlay-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the development headers for the overlay component.

%package -n libOgreVolume-devel
Summary:        Development files for the Ogre Volume component
Group:          Development/Libraries/C and C++
Requires:       libOgreVolume%{soname} = %{version}

%description -n libOgreVolume-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the development headers for the volume component.

%package -n libOgreRTShaderSystem-devel
Summary:        Development files for the OGRE Runtime Shader System component
Group:          Development/Libraries/C and C++
Requires:       libOgreRTShaderSystem%{soname} = %{version}

%description -n libOgreRTShaderSystem-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the development headers for the Runtime Shader System
(RTSS) component.

%package -n libOgreTerrain-devel
Summary:        Development files for the Ogre Terrain System component
Group:          Development/Libraries/C and C++
Requires:       libOgreTerrain%{soname} = %{version}

%description -n libOgreTerrain-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the development headers for the Ogre Terrain System.

%package devel
Summary:        Development files for the Ogre Engine
Group:          Development/Libraries/C and C++
Requires:       pkgconfig(OGRE)
Requires:       pkgconfig(OGRE-Bites)
Requires:       pkgconfig(OGRE-MeshLodGenerator)
Requires:       pkgconfig(OGRE-Overlay)
Requires:       pkgconfig(OGRE-Paging)
Requires:       pkgconfig(OGRE-Property)
Requires:       pkgconfig(OGRE-RTShaderSystem)
Requires:       pkgconfig(OGRE-Terrain)
Requires:       pkgconfig(OGRE-Volume)

%description devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

%package -n ogre-demos
Summary:        Ogre demo programs
Group:          Development/Libraries/C and C++
Requires:       %{name}-media = %{version}
Requires:       libOgreMain%{soname}-plugins = %{version}
%if %{with cg}
Requires:       libOgreMain%{soname}-plugin-Cg = %{version}
%endif

%description -n ogre-demos
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented 3D engine.

This package contains the demo applications.

%package -n ogre-demos-devel
Summary:        Sources for the Ogre demo programs
Group:          Development/Sources
Requires:       libOgreRTShaderSystem-devel = %{version}
Requires:       libOgreTerrain-devel = %{version}

%description -n ogre-demos-devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible
3D engine written in C++ designed to make it easier and more intuitive for
developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

This package contains the source of the demo applications.

%package -n ogre-tools
Summary:        Additional utilities for working with the Ogre 3D engine
Group:          Development/Libraries/C and C++

%description -n ogre-tools
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible
3D engine written in C++ designed to make it easier and more intuitive for
developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

This package contains various tools that make working with ogre easier.

%package -n ogre-docs
Summary:        Documentation for the Ogre 3D engine
Group:          Documentation/Other

%description -n ogre-docs
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible
3D engine written in C++ designed to make it easier and more intuitive for
developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

This package contains the documentation for OGRE.

%prep
%setup -q -a1
%autopatch -p1
dos2unix ./Docs/ogre_style.css

%build
mkdir %{__builddir}
ln -s {..,%{__builddir}}/imgui-%{im_version}
%cmake \
      -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DOGRE_LIB_DIRECTORY=%{_lib} \
      -DOGRE_BUILD_SAMPLES=ON \
      -DOGRE_INSTALL_DOCS=ON \
      -DOGRE_PLUGINS_PATH="%{_lib}/OGRE%{soname}" \
      -DOGRE_BUILD_RENDERSYSTEM_VULKAN=ON \
      -DOGRE_BUILD_DEPENDENCIES=OFF
%cmake_build

%install
%cmake_install
%if %{without mono}
rm %{buildroot}%{_includedir}/OGRE/Ogre.i
%endif
mkdir -p "%{buildroot}%{_docdir}"
mv "%{buildroot}%{_datadir}/doc/OGRE" "%{buildroot}%{_docdir}/OGRE"
# Install samples' source
mkdir -p %{buildroot}%{_datadir}/OGRE
cp -R Samples %{buildroot}%{_datadir}/OGRE/
# create a dummy target for /etc/alternatives/ogre (plugins config)
mv %{buildroot}%{_datadir}/OGRE/plugins.cfg %{buildroot}%{_datadir}/OGRE/plugins%{sover}.cfg
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/ogre %{buildroot}%{_datadir}/OGRE/plugins.cfg
# Fix file and directory permissions
find %{buildroot}%{_datadir}/OGRE/ -type f -exec chmod 0644 \{\} +
find %{buildroot}%{_datadir}/OGRE/ -type d -exec chmod 0755 \{\} +
# Remove duplicates
%fdupes %{buildroot}%{_includedir}/OGRE
%fdupes %{buildroot}%{_datadir}

%post -n libOgreMain%{soname}-plugins
update-alternatives --install \
  %{_datadir}/OGRE/plugins.cfg \
  ogre \
  %{_datadir}/OGRE/plugins%{sover}.cfg \
  $(printf '%02d%02d' %{major} %{minor})

%postun -n libOgreMain%{soname}-plugins
if [ ! -f %{_datadir}/OGRE/plugins%{sover}.cfg ] ; then
   update-alternatives --remove ogre %{_datadir}/OGRE/plugins%{sover}.cfg
fi

%post -n libOgreBites%{soname} -p /sbin/ldconfig
%postun -n libOgreBites%{soname} -p /sbin/ldconfig
%post -n libOgreBitesQt%{soname} -p /sbin/ldconfig
%postun -n libOgreBitesQt%{soname} -p /sbin/ldconfig
%post -n libOgreMain%{soname} -p /sbin/ldconfig
%postun -n libOgreMain%{soname} -p /sbin/ldconfig
%post -n libOgreMeshLodGenerator%{soname} -p /sbin/ldconfig
%postun -n libOgreMeshLodGenerator%{soname} -p /sbin/ldconfig
%post -n libOgrePaging%{soname} -p /sbin/ldconfig
%postun -n libOgrePaging%{soname} -p /sbin/ldconfig
%post -n libOgreProperty%{soname} -p /sbin/ldconfig
%postun -n libOgreProperty%{soname} -p /sbin/ldconfig
%post -n libOgreVolume%{soname} -p /sbin/ldconfig
%postun -n libOgreVolume%{soname} -p /sbin/ldconfig
%post -n libOgreOverlay%{soname} -p /sbin/ldconfig
%postun -n libOgreOverlay%{soname} -p /sbin/ldconfig
%post -n libOgreRTShaderSystem%{soname} -p /sbin/ldconfig
%postun -n libOgreRTShaderSystem%{soname} -p /sbin/ldconfig
%post -n libOgreTerrain%{soname} -p /sbin/ldconfig
%postun -n libOgreTerrain%{soname} -p /sbin/ldconfig

%files -n libOgreMain%{soname}
%license LICENSE
%dir %{_libdir}/OGRE
%{_libdir}/libOgreMain.so.%{sover}

%files media
%dir %{_datadir}/OGRE
%dir %{_datadir}/OGRE/Media
%{_datadir}/OGRE/resources.cfg
%{_datadir}/OGRE/Media/Main
%{_datadir}/OGRE/Media/RTShaderLib
%{_datadir}/OGRE/Media/Terrain/

%if %{with mono}
%files mono
%{_includedir}/OGRE/Ogre.i
%dir %{_prefix}/lib/cli
%dir %{_prefix}/lib/cli/ogre-sharp-%{version}
%{_prefix}/lib/cli/ogre-sharp-%{version}/Ogre.dll
%{_prefix}/lib/cli/ogre-sharp-%{version}/libOgre.so
%endif

%files python
%{python3_sitelib}/Ogre

%files -n libOgreMain%{soname}-codecs
%{plugin_dir}/Codec_Assimp.so{,.%{sover}}
%{plugin_dir}/Codec_FreeImage.so{,.%{sover}}
%{plugin_dir}/Codec_STBI.so{,.%{sover}}
%if %{with openexr}
%{plugin_dir}/Codec_EXR.so{,.%{sover}}
%endif

%files -n libOgreMain%{soname}-plugins
%dir %{plugin_dir}
%{_datadir}/OGRE/plugins%{sover}.cfg
%{_datadir}/OGRE/plugins.cfg
%ghost %{_sysconfdir}/alternatives/plugins.cfg
%{plugin_dir}/RenderSystem_GL.so{,.%{sover}}
%{plugin_dir}/RenderSystem_GL3Plus.so{,.%{sover}}
%{plugin_dir}/RenderSystem_GLES2.so{,.%{sover}}
%{plugin_dir}/RenderSystem_Vulkan.so{,.%{sover}}
%{plugin_dir}/Plugin_BSPSceneManager.so{,.%{sover}}
%{plugin_dir}/Plugin_DotScene.so{,.%{sover}}
%{plugin_dir}/Plugin_OctreeZone.so{,.%{sover}}
%{plugin_dir}/Plugin_OctreeSceneManager.so{,.%{sover}}
%{plugin_dir}/Plugin_ParticleFX.so{,.%{sover}}
%{plugin_dir}/Plugin_PCZSceneManager.so{,.%{sover}}
%{plugin_dir}/Plugin_GLSLangProgramManager.so{,.%{sover}}

%if %{with cg}
%files -n libOgreMain%{soname}-plugin-Cg
%dir %{plugin_dir}
%{plugin_dir}/Plugin_CgProgramManager.so{,.%{sover}}
%endif

%files -n libOgreBites%{soname}
%{_libdir}/libOgreBites.so.%{sover}

%files -n libOgreBitesQt%{soname}
%{_libdir}/libOgreBitesQt.so.%{sover}

%files -n libOgreMeshLodGenerator%{soname}
%{_libdir}/libOgreMeshLodGenerator.so.%{sover}

%files -n libOgrePaging%{soname}
%{_libdir}/libOgrePaging.so.%{sover}

%files -n libOgreProperty%{soname}
%{_libdir}/libOgreProperty.so.%{sover}

%files -n libOgreOverlay%{soname}
%{_libdir}/libOgreOverlay.so.%{sover}

%files -n libOgreVolume%{soname}
%{_libdir}/libOgreVolume.so.%{sover}

%files -n libOgreRTShaderSystem%{soname}
%{_libdir}/libOgreRTShaderSystem.so.%{sover}

%files -n libOgreTerrain%{soname}
%{_libdir}/libOgreTerrain.so.%{sover}

%files -n libOgreMain-devel
%dir %{_includedir}/OGRE/
%{_includedir}/OGRE/*.h
%{_includedir}/OGRE/Plugins/
%{_includedir}/OGRE/RenderSystems/
%{_includedir}/OGRE/Threading/
%{_libdir}/libOgreMain.so
%{_libdir}/pkgconfig/OGRE.pc
%{_libdir}/pkgconfig/OGRE-PCZ.pc

%files -n libOgreBites-devel
%{_includedir}/OGRE/Bites/
%{_libdir}/libOgreBites.so
%{_libdir}/libOgreBitesQt.so
%{_libdir}/pkgconfig/OGRE-Bites.pc

%files -n libOgreMeshLodGenerator-devel
%{_includedir}/OGRE/MeshLodGenerator
%{_libdir}/libOgreMeshLodGenerator.so
%{_libdir}/pkgconfig/OGRE-MeshLodGenerator.pc

%files -n libOgrePaging-devel
%{_includedir}/OGRE/Paging/
%{_libdir}/libOgrePaging.so
%{_libdir}/pkgconfig/OGRE-Paging.pc

%files -n libOgreProperty-devel
%{_includedir}/OGRE/Property/
%{_libdir}/libOgreProperty.so
%{_libdir}/pkgconfig/OGRE-Property.pc

%files -n libOgreVolume-devel
%{_includedir}/OGRE/Volume/
%{_libdir}/libOgreVolume.so
%{_libdir}/pkgconfig/OGRE-Volume.pc

%files -n libOgreOverlay-devel
%{_includedir}/OGRE/Overlay/
%{_libdir}/libOgreOverlay.so
%{_libdir}/pkgconfig/OGRE-Overlay.pc

%files -n libOgreRTShaderSystem-devel
%{_includedir}/OGRE/RTShaderSystem/
%{_libdir}/libOgreRTShaderSystem.so
%{_libdir}/pkgconfig/OGRE-RTShaderSystem.pc

%files -n libOgreTerrain-devel
%{_includedir}/OGRE/Terrain/
%{_libdir}/libOgreTerrain.so
%{_libdir}/pkgconfig/OGRE-Terrain.pc

%files devel
%doc AUTHORS README.md
%{_libdir}/OGRE/cmake/

%files -n ogre-demos
%{_libdir}/OGRE/Samples/
%{_bindir}/SampleBrowser
%{_datadir}/OGRE/Media/*
%exclude %{_datadir}/OGRE/Media/Main
%exclude %{_datadir}/OGRE/Media/RTShaderLib
%exclude %{_datadir}/OGRE/Media/Terrain/
%{_datadir}/OGRE/GLX_backdrop.png
%{_datadir}/OGRE/samples.cfg

%files -n ogre-demos-devel
%{_datadir}/OGRE/Samples

%files -n ogre-tools
%{_bindir}/OgreMeshUpgrader
%{_bindir}/OgreXMLConverter
%{_bindir}/VRMLConverter
%{_bindir}/OgreAssimpConverter

%files -n ogre-docs
%doc %{_docdir}/OGRE

%changelog
* Thu May  2 2024 Ferdinand Thiessen <rpm@fthiessen.de>
- Disable mono bindings by default to fix build on Tumbleweed
* Tue Jan 30 2024 Michael Pujos <pujos.michael@gmail.com>
- fixed compilation with glslang v14
- added fix-glslang-plugin-compilation.patch
* Mon Dec 18 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Added fix-gslang-cpp17.patch to fix build with our current GLSlang package
- Update to 13.6.5
  * DeflateStream can throw in close() > compressFinal()
  * fix element count of ACT_TIME_0_*
  * fix ResourceGroupManager shutdown crash
  * GpuProgramParameters - assert correct autoconstant type
  * SceneManager - report derived material in renderdoc
  * Technique - avoid deadlock when shadow_*_material refers to self
  * use identity for *VIEWPROJ_MATRIX if textureProjector is NULL
  * RTSS
  * normalmap - parallax texcoord should also affect normalmap lookup
  * IBL - ensure envmap is used as cubic texture
  * GLSupport: early-out if shader source is empty
  * GLES2/GL3+: fix HardwareBuffer::copyData when offsets are not 0
  * GLES2: fix check in blitFromMemory
- Update to 13.6.4
  * LiSPSMShadowCameraSetup::create - actually forward the params
  * Mesh - actually only trigger assertion in debug mode
  * Resource - call prepareResource() before loading an unprepared
    manual resource
  * MeshUpgrader - avoid assertion in ~Mesh
  * XMLConverter: XMLSkeletonSerializer - use correct bone handles
    for createNodeTrack()
  * STBICodec: update embedded STB Image
- Update to 13.6.3
  * CompositorInstance - fix auto-sorting custom render passes
  * setBonesUseObjectSpace - use the passed value
  * RTSS
  * cook torrance - forward surface alpha
  * Do not add the gl_PerVertex block when writing the shader.
- Update to 13.6.2
  * GpuProgramParameters - do not set variability in clearAutoConstant
  * move RSC compatibility check to useCustomRenderSystemCapabilities
  * Assimp:
  * set emissive to 0 when using an emissive map
  * support loading embedded textures
  * GL: RenderToVertexBuffer - fix detection of GLSL shaders
  * GLSupport
  * EGL - fix multi-window operation
  * fix requested version of GL context
- Update to 13.6.1
  * GLES2: Better handle the case where we dont have texture_border_clamp
  * Emscripten: dynamically switch to WebGL2, if possible
  * RTSS: fix parsing triplanarTexturing params
- Update to 13.6.0
  * Image Based Lighting provided by the RTSS
  * Terrain shaders generated by the RTSS
  * significantly improved shadowing quality
  * Rust based image codec
  * Full changes: https://github.com/OGRECave/ogre/releases/tag/v13.6.0
* Mon Jun  5 2023 Andreas Schwab <schwab@suse.de>
- Add option to build without mono bindings
* Fri Nov 25 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 13.5.3
  * Minor RTSS and TerrainTransform fixes
- Update to 13.5.2
  * Various GL bugfixes
- Update to 13.5.1
  * RenderSystem - skip FFP texture settings when FFP is not supported
  * Minor RTSS bugfixes
- Update to 13.5.0
  * Implement Automatic Instancing
  * Add support for GPU bone to world transform
  * Non shadow-casting lights and PSSM integration
  * Use Vulkan Memory Allocator
  * See full changes:
    https://github.com/OGRECave/ogre/releases/tag/v13.5.0
- Add swig-3-cpp11.patch required for swig 3 on openSUSE Leap 15.3
  and Leap 15.4
- Add fix-sse-detection.patch for fixing sse detection, as x86 does
  not always provides sse, only x64 has always sse support
* Fri Nov 25 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 13.4.4
  * Minor bug fixes, especially within the GLSLang and Vulkan part
- Update to 13.4.3
  * Refactor code to C++11 style
  * Fixes within ParticleFX and RTSS
- Update to 13.4.2
  * Minor bug fixes, focussed on RTSS and PCZSceneManager
- Update to 13.4.1
  * BillboardChain - fix orientation when there is only one camera
- Update to 13.4.0
  * Add Bullet component based on BtOgre
  * Add VET_INT_10_10_10_2_NORM
  * Add basic support for joystick devices
  * Overlay: update ImGui to 1.87
  * Full changes: https://github.com/OGRECave/ogre/releases/tag/v13.4.0
- Rebased 0001-Vulkan-Use-find_package-to-support-system-wide-insta.patch
* Wed Apr  6 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 13.3.4
  * GL3+: improved performance by 10%% when draw-call bound
  * Codec_Assimp: allow loading glTF2 meshes
  * RTSS: PBR material support
  * Improved Gamepad Support via Bites
  * Bites: also scale button events on OSX
  * RTSS: PSSM3 - use projective space splits to allow reversed-Z
  * Vulkan: implement Reversed Depth mode
- Remove upstream merged patches
  * 0001-Fix-plugins-not-installed-into-OGRE_PLUGINS_PATH.patch
  * ff55ef7b272fa0fb5be935ac41af67f5d6e15bf4.patch
  * fix-assimp-cmake.patch
- python3-sitelib.patch is now openSUSE specific, upstream voted
  against it.
- Rebased 0001-Vulkan-Use-find_package-to-support-system-wide-insta.patch
* Tue Dec 21 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Use update-alternatives for plugin.cfg
* Thu Dec 16 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 13.2.4
  * PixelFormat: use red channel when packing PF_A8 to match OpenGL
  * Ogre.h: include OgreUnifiedHighLevelGpuProgram.h
  * Vulkan:
  * add swizzling for PF_A8
  * enable PF_DEPTH32
- Add ff55ef7b272fa0fb5be935ac41af67f5d6e15bf4.patch from upstream
  fixes linking issues with version 13.2.2+
- Update to 13.2.1
  * Frustum: deprecate getProjectionMatrixRS
  * Mesh: drop mSkeletonName as it always matches mSkeleton
  * update zip/ miniz to 2.2.0
  * Media: drop obsolete HLMS shaders
  * RTSS: allow targeting glslang
  * Overlay: fix missing bits for HiDPI support
  * Terrain: GLSL - add Vulkan support
  * GLSLang: use latest GLSL version to get all features
  * Vulkan: add new RenderSystem based on ogre-next version
  * GL*: drop superflous GLHardwarePixelBuffer indirection
  * update imgui to 1.85
  * Many other features and bug fixes, full list is available:
    https://github.com/OGRECave/ogre/releases/tag/v13.2.0
- Added 0001-Fix-plugins-not-installed-into-OGRE_PLUGINS_PATH.patch
  install plugins into configured plugin path
- Added 0001-Vulkan-Use-find_package-to-support-system-wide-insta.patch
  support system wide installed vulkan.
* Tue Dec 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 13.1.1
  * add Rectangle2D to Ogre.h
  * Deprecated - drop duplicate definition of aligned_vector
  * RTSS: implement two-sided lighting
  * Bites: Use Qt 6 for OgreBitesQt if present
  * UnifiedShader:
  * add texture2DArray support and refactor respective sample
  * initial support for glslang
  * GLSLang: enable standard params & add vulkan support
  * Many other features and bug fixes, full list is available:
    https://github.com/OGRECave/ogre/releases/tag/v13.1.0
* Tue Dec 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 13.0.1, version scheme changed. With breaking changes:
  * Deprecated std wrappers and SceneType into OgreDeprecated.h
  * Several private structures are not exposed anymore
  * Dopped
  * "Custom Render Queues" support
  * deprecated SceneLoader API
  * long-standing hard deprecations
  * most of texture_alias API
  * ParticleIterator
  * _StringBase & _StringStreamBase indirection
  * subroutine API in favor of specialization constants
  * support for TEX_TYPE_2D_RECT
  * rename Media/ShadowVolume to Media/Main
  * add API for exporting scene hierarchy + dotscene implementation
  * add GLSLang shader compiler plugin
  * Many other new features and bug fixes, full list available:
    https://github.com/OGRECave/ogre/releases/tag/v13.0.0
* Fri Dec 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.12.13
  * Add API for exporting scene hierarchy + dotscene implementation
  * DDSCodec - disable mips instead of decompressing
  * FileSystemLayer - also look relative to lib for configs on Linux
  * MaterialSerializer - do not export RTSS techniques by default
  * Root - catch bad config options in restoreConfig
  * SceneManager::createLight - add convenience param to specify Type
  * TRect - add asserts to merge & intersect
  * Viewport - disable clearBuffers if clearEveryFrame is off
  * Overlay: Font - Texture must be removed to allow reloading
  * Terrain: Delete plane when shutting down.
  * A lot bug fixes
- Add fix-assimp-cmake.patch, fixes assimp detection by cmake
* Mon Sep  6 2021 Adam Mizerski <adam@mizerski.pl>
- Ogre is incompatible with OpenEXR v3. OpenEXR is an optional
  dependency, so disable it for now using %%bcond_with.
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.12.12
  * See https://github.com/OGRECave/ogre/releases/tag/v1.12.12
- Refresh python3-sitelib.patch
- Install versioned modules, unversioned only for devel package
- Add virtual devel package, the cmake module requires all devel
  package
* Sun Apr 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.12.11
  * A lot of new features and bug fixes, please refer to
    https://github.com/OGRECave/ogre/releases/tag/v1.12.11
    Or the release notes provided in ogre-docs packge (Notes*.md)
- Added python and CSharp subpackages
- Added python3-sitelib.patch for correct python site-lib path
- Dropped upstream fixed patches
  * riscv64-architecture.patch
  * fix-aarch64-detection.patch
  * fix-template-function.patch
  * ogre-1.9.0-fixsled.patch
  * ogre1.9.0-browser-cmake.patch
  * ogre-1.9.0-texturearray-ambig-uint.patch
  * ogre-1.9.0-longlongconstants.patch
* Mon Jan 11 2021 Andreas Schwab <schwab@suse.de>
- riscv64-architecture.patch: add riscv64 as 64bit architecture
* Fri Jul 24 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with default min 4GB disk
  and specifically for PowerPC set min 6GB physicalmemory.
* Tue Jan  2 2018 stefan.bruens@rwth-aachen.de
- Fix aarch64 build, add fix-aarch64-detection.patch
- Fix armv{6,7}l build, set flags for zzip (same as i586)
* Fri Dec  8 2017 mimi.vx@gmail.com
- fix boost BuildRequires
* Sun Sep 25 2016 jengelh@inai.de
- Trim repetitive descriptions and include more details on what
  the components do.
* Thu Sep 15 2016 mimi.vx@gmail.com
- don't build Cg plugin.
* Sat Sep 10 2016 mimi.vx@gmail.com
- change macro for _version, obs-source-validator can't expand
    complex macros
* Tue Nov 24 2015 rpm@fthiessen.de
- Added fix-template-function.patch from fedora to resolve link
  errors due to incorrect template creation.
  Needed for openSUSE Factory.
* Tue Mar 11 2014 Rene.vanPaassen@gmail.com
- removing the platform inttypes patch, did not solve anything
- correcting the unsigned long long constants in
  OgrePixelFormatDescriptions.h, this tripped on sles 11 (older gcc)
* Mon Mar 10 2014 Rene.vanPaassen@gmail.com
- use platform inttypes.h for sles
* Mon Mar 10 2014 Rene.vanPaassen@gmail.com
- fixed Samples/Browser/CMakeLists.txt for new cmake 3.0.0 (does
  not permit [ ] in command
- added explicit template instantiation to
  OgreMain/src/OgreProgressiveMeshGenerator.cpp for sled/sles
- explicitly indicate source of uint in
  Samples/TextureArray/include/TextureArray.h
* Mon Jan  6 2014 Rene.vanPaassen@gmail.com
- fix UTF-8 BOM problem for older gcc (sles 11)
* Mon Dec  9 2013 opensuse@dstoecker.de
- update to 1.9.0
* Fri Nov 22 2013 Rene.vanPaassen@gmail.com
- openSUSE 13.1 is not zzip_largefile_sensitive
* Thu Nov  7 2013 Rene.vanPaassen@gmail.com
- adjust flags for using the zzip lib with large file calls on
  newer zzip; for sles and opensuse factory. Only affects i586 builds
* Mon Oct  1 2012 Rene.vanPaassen@gmail.com
- remove the -Wno-unused-but-set-parameter for sles builds
* Sun Sep 23 2012 mailaender@opensuse.org
- Update to upstream release 1.8.1
  - [GLES2] Add missing shader for skeletal sample
  - Fix crashes in OS X template code.
  - [OS X] Resolve some issues with visibility of symbols preventing universal builds.
  - [GLES] Improvements to pixel format selection. Reduces conversions at runtime and enables more formats.
  - Fix a couple defines in GLEW headers that I mistakenly altered during a batch replace. Resolves issues with FSAA on Windows using OpenGL
  - Disabling X11 check for all Apple platforms. Because it may not always be available on the system.
  - Fix a bug with OctreeNodes that are not in the scene graph being updated improperly. As reported in viewtopic.php?f=4&t=70617&p=461051
  - Patch 3517455 – Rename the COPYING file due to CPack not allowing files without extensions.
  - Patch 3526568 – Fix for when a listener object unreferences itself from the listened object while in a callback
  - Patch 3525902 – SceneManager – Fix for when a listener object unreferences itself from the listened object while in a callback
  - Bug 521 – Copy the flag to control auto edge list building when cloning a mesh.
  - Bug 532 – Default values not being returned on invalid input to StringConverter::parse* functions
  - Patch 3519819 – Add missing setRenderQueueGroupAndPriority functions to ParticleSystem and BillboardParticleRenderer.
  - OS X – Fix the “invalid drawable” error that pops up in the log when a window is created.
  - Patch 3324815 – Fix incorrect zip archive behavior. This also fixes a few of our unit tests.
  - Add a missing capabilities mapping
  - Fix up the Xcode 4 template
  - iOS: Fix crash caused by missing GL function pointers with GLES 2 on iOS 4
  - Revert part of a change that I made several months ago that was causing problems with texture shadows without edge lists.
  - Bug 538 – Support for boost 1.50
  - Bug 536 – Freetype 2.4.10
  - Fix [3538257]: Listener was never actually removed in SceneManager::removeListener
  - added check for icon existance in bool GLXGLSupport
  - Made SimpleRenderable::setMaterial virtual.
  - [OS X] Use the path from the FindCg script to create the framework symlink instead of assuming the prebuilt dependencies are being used.
  - Add a missing semicolon that has been causing some compile errors when using boost for threading.
  - Moved call to wglShareLists before call to wglMakeCurrent to help Wine emulation
  - [D3D9] Catch texture load exception in D3D9Texture::notifyOnDeviceCreate to prevent Ogre from crashing when moved to a new display
  - [Papercut] Resolve ambiguity of get/setUserAny in InstanceBatch
  - Fix [3545669]: Submesh operation type is not passed to tangent calculator causing triangle strips and fans to have improper tangents
  - Fix [3542148] Properly set texture coordinate index in D3D9 if vertex program is used with projective texturing
  - Fix [3538259]: Use _tempnam on Windows to generate temporary file name in OgreDeflate.cpp
  - Fix [3535939]: In CompositorInstance::getTargetForTex search also for referenced texture name if referencing another compositor’s texture
  - [3531905] Fix a bug in LOD generation of XSI exporter
  - [3531904] Update FindSoftimage.cmake to find Softimage 2013
  - Applied and enhanced masterfalcon’s patch to prevent BillboardChains from
  - updating their vertex buffer except when they are actually being rendered.
  - Fixed ParticleSystem’s emitted emitters ‘sputtering’ when emission rate per frame near 1/2.
  - Fix [522]: D3D9 / D3D11 destroyRenderTarget caused dangling pointer inside RS’s
  - Fix [504]: D3D9 Prevent infinite loop when CheckDeviceMultiSampleType fails when
  - fsaa is 0
  - Fix [454]: D3D9 add more error details when we can not create a vertex shader
  - [3484580] Fix a potential crash when loading materials referencing non-existent shadow caster/receiver materials
  - Increased size of GLX config dialog to accomodate for additional GL RenderSystem option
  - TerrainGroup did not pass along parameters to underlying Terrain in update and updateDerivedData
  - Fix [541]: In Rev 3513 the warning texture is created with a invalid context so
  - the gl id was 0 – this broke materials without valid textures (if no texture is
  - bounded the warning texture is bound)
  - Fix for possible endless loop if requesting max number of mipmaps with 0 depth. Affects all GL render systems.
  - Fixed -msse flag when building with MinGW.
  - [OS X] Fix displaying garbage on first frame when using Cocoa windows.
  - Also fixing the “invalid drawable” error.
  - Fix incorrect header guard.
  - Replace an ugly hack for GCC that was trying to force 16-byte stack alignment in OgreOptimisedUtilSSE, but causes trouble with recent GCC versions
  - GLES/GLES2 move error checks into the right place
  - Fixed bug: D3D9 can now be compiled in static with MinGW.
  - Get PlayPen and VTests running with static builds like iOS. Also some minor code cleanup.
  - Patches 3506252 & 3535295 – Profiler enhancements and support for GPU profile events.
  - Fix [541]: viewportDestroyed were never called
  - Fix a crash when starting/stopping the terrain sample with shadowing enabled. House entities need to be freed.
  - Fix [549]: When ogre is compiled with profiler support link dx9 to dx11 so we can
  - use D3DPERF_BeginEvent/D3DPERF_EndEvent/D3DPERF_SetMarker
  - Fix some profiler crashes
  - Bugfix: Instancing LOD distance strategy was considering entities that were not in the scene.
  - Bugfix: Instancing LOD distance strategy was using very inaccurate distance formula.
  - Bug 545: ScriptLexer is counting \r\n as 2 newlines
  - Patch 3505652 – Fix for compositors recompiling every frame
  - Patch 3489471 – Entity LOD animation bugfix
  - Fixed a bug in the CMakeLists.txt that would cause an error when the user
  - influences CMAKE_CXX_FLAGS manually in CMake.
  - [GLES2] Attempt to resolve the isAttributeValid crash when shaders are either missing or have failed to compile/link. Also do a little more logging when reporting compile errors.
  - Calling removeInstancedEntity on the same InstancedEntity more than once will now raise an exception.
  - [iOS] Remove old GCC define to disable thumb and use a compiler flag instead. More reliable across gcc and clang.
  - Make it possible to call Viewport::removeListener during viewportDestroyed event
  - [OS X] Correctly compute Cocoa window origins and fix repositioning.
  - HW-Instancing: Add support for meshes which use a shared vertex buffer
  - Fixed the NaCl compile and link for the latest code changed in 1.8
  - Fixed texture loading issues in GLES2 RS for NaCl.
  - Changed RenderSystems on Windows to interpret externalWindowHandle and parentWindowHandle parameters as size_t instead of unsigned int, which has the wrong size on 64bit platforms
  - Fix Unity builds for OSX (SampleBrowser did not compile)
* Sun Jul  1 2012 devel.openSUSE.org@gmail.com
- Update to upstream release 1.8.0
  - Terrain changes
  - Terrain vertex data is now compressed by default, reducing the vertex size by 40%% on the GPU
  - Terrain data is saved in a compressed format (Deflate) resulting in smaller disk sizes (uncompressed data files are still supported)
  - DeflateStream added
  - Wraps any other stream to compress / decompress data via the deflate algorithm
  - If given an uncompressed stream to load, automatically falls back on a passthrough read for easy compatibility
  - Vertex normals can now be animated in morph and pose animation
  - Normals can be included in vertex morph keyframes, and specified as part of reference poses
  - Software, SSE and hardware (shader) pipelines supported
  - Mesh format has been upgraded to support the new data
  - Note: Animated normals are currently not compatible with stencil shadows because of the conflicting vertex structure requirements
  - Versioned mesh writing
  - MeshSerializer can now write all versions of .mesh back to Ogre 1.0 rather than only being able to write in the latest version format. This should make it easier for tool & exporter developers who can use the latest code but still support users on older versions
  - OgreMeshUpgrader now accepts an optional -V parameter where you can specify the target version to write
  - New Instancing system
  - Completely new InstanceManager system written from scratch, which is more robust, supports extending it with multiple techniques
  - Interface and behavior very similar to Entity, to mantain consistency and allow easy switch between Entities and Instanced Entities. Instanced Entities can be attached to scene nodes.
  - Implemented ShaderBased technique (up to 80 instances per batch, matrices stored in vertex shader's constant registers)
  - Implemented VTF technique (huge ammount of instances per batch stored in a texture, needs Vertex Texture Fetch)
  - Added "New Instancing" sample to show the capabilities, limits, and features of this new system.
  - A cache of the binary representation of shaders.
* Mon May 14 2012 Rene.vanPaassen@gmail.com
- Fixed a typo, %%{verion} should be %%{version} (calculated wrong
  provides and failed on SLE 11, not on later platforms)
- Added Requires:libOgreMain-devel to the other devel packages
* Fri Apr 20 2012 joop.boonen@opensuse.org
- Removed Plugin directory patches
  - Haven't been accepted in the source code
  - Makes alligning dependent packages more difficult
- Corrected some dependancies
- Added some Provides
* Sun Feb 26 2012 joop.boonen@opensuse.org
- Build ogre 1.7.4
* Fri Nov 25 2011 Rene.vanPaassen@gmail.com
- As per the openSUSE:Specfile_guidelines, the BuildRoot tag should
  always be used (and build fails on SLE without)
- Removed the alternative dependencies again, put them as
  Substitute: into project configuration
* Thu Nov 24 2011 Rene.vanPaassen@gmail.com
- Provided alternative dependencies for sled
* Mon Oct  3 2011 reddwarf@opensuse.org
- Update to OGRE 1.7.3
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Sun Apr 25 2010 cmorve69@yahoo.es
- Update to OGRE 1.7.1
* Sat Apr 24 2010 cmorve69@yahoo.es
- Made libOgreMain-devel require boost-devel
* Thu Aug  6 2009 cmorve69@yahoo.es
- Respect the Shared Library Naming and Packaging Policy
- Added missing Provides/Obsoletes to allow the upgrade after the -plugins merge
* Wed Aug  5 2009 cmorve69@yahoo.es
- Update to OGRE 1.6.3
- Merge -plugins subpackage in main package
* Mon Apr 27 2009 matt@milliams.com
- Update to OGRE 1.6.2
* Sun Apr  5 2009 dominique-obs@leuenberger.net
- package rename libdevil-devel -> DevIL-devel
* Sat Dec  6 2008 dominique-obs@leuenberger.net
- Added patch to successfully build on 11.1 and Factory
* Fri Nov 14 2008 matt@milliams.com
- Update to OGRE 1.6.0
* Tue Mar 25 2008 matt@milliams.com
- Build with DevIL rather than FreeImage to avoid conflicts with system libraries
* Wed Mar 12 2008 prusnak@suse.cz
- Updated to OGRE 1.4.7
* Wed Jan 23 2008 prusnak@suse.cz
- Updated to OGRE 1.4.6
- drop includes.patch
* Mon Dec 17 2007 prusnak@suse.cz
- Updated to OGRE 1.4.5
- Fix missing includes (includes.patch)
* Tue Aug  7 2007 matt@milliams.com
- Updated to OGRE 1.4.3
- Renamed ogre(-devel) package to libogre(-devel)
* Tue Jan  9 2007 kai.blin@gmail.com
- Initial spec file for ogre 1.2.4
